==> ShopMadeSimple0.3.2.zip: ShopMadeSimple/method.uninstall.php <==
<?php
$gCms = cmsms(); if( !is_object($gCms) ) exit;

// Drop all tables
$db = cmsms()->GetDb();
$dict = NewDataDictionary($db);

$sqlarray = $dict->DropTableSQL(cms_db_prefix().'module_sms_categories');
$dict->ExecuteSQLArray($sqlarray);		
$sqlarray = $dict->DropTableSQL(cms_db_prefix().'module_sms_products');
$dict->ExecuteSQLArray($sqlarray);				
$sqlarray = $dict->DropTableSQL(cms_db_prefix().'module_sms_product_images');
$dict->ExecuteSQLArray($sqlarray);				
$sqlarray = $dict->DropTableSQL(cms_db_prefix().'module_sms_product_attributes');
$dict->ExecuteSQLArray($sqlarray);				
$sqlarray = $dict->DropTableSQL(cms_db_prefix().'module_sms_product_skus');
$dict->ExecuteSQLArray($sqlarray);				
$sqlarray = $dict->DropTableSQL(cms_db_prefix().'module_sms_product_category');
$dict->ExecuteSQLArray($sqlarray);				

// Remove all preferences
$this->RemovePreference();

// Remove security permissions
$this->RemovePermission('ShopMS_UseShopMadeSimple');
$this->RemovePermission('ShopMS_MaintainCategory');
$this->RemovePermission('ShopMS_MaintainProducts');
$this->RemovePermission('ShopMS_MaintainSKUs');

// Remove style sheet that belong to this module
$css_name = $this->Lang('module_example_stylesheet'); // Retrieve the name of the new stylesheet locate in the css directory
$query = 'DELETE FROM '.cms_db_prefix().'css WHERE css_name = ?';
$db->Execute($query, array($css_name));

// Remove all the search index entries
$searchmodule =& $this->GetModuleInstance('Search');
if ($searchmodule != FALSE) {
	$searchmodule->DeleteWords($this->module->GetName());
}

// Remove templates that belong to this module
$this->DeleteTemplate('', 'ShopMadeSimple');

$this->Audit( 0, $this->Lang('friendlyname'), $this->Lang('uninstalled',$this->GetVersion()));
?>

==> ShopMadeSimple-0.3.4.zip: ShopMadeSimple/method.uninstall.php <==
<?php
$gCms = cmsms(); if( !is_object($gCms) ) exit;

// Drop all tables
$db = cmsms()->GetDb();
$dict = NewDataDictionary($db);

$sqlarray = $dict->DropTableSQL(cms_db_prefix().'module_sms_categories');
$dict->ExecuteSQLArray($sqlarray);		
$sqlarray = $dict->DropTableSQL(cms_db_prefix().'module_sms_products');
$dict->ExecuteSQLArray($sqlarray);				
$sqlarray = $dict->DropTableSQL(cms_db_prefix().'module_sms_product_images');
$dict->ExecuteSQLArray($sqlarray);				
$sqlarray = $dict->DropTableSQL(cms_db_prefix().'module_sms_product_attributes');
$dict->ExecuteSQLArray($sqlarray);				
$sqlarray = $dict->DropTableSQL(cms_db_prefix().'module_sms_product_skus');
$dict->ExecuteSQLArray($sqlarray);				
$sqlarray = $dict->DropTableSQL(cms_db_prefix().'module_sms_product_category');
$dict->ExecuteSQLArray($sqlarray);				

// Remove all preferences
$this->RemovePreference();

// Remove security permissions
$this->RemovePermission('ShopMS_UseShopMadeSimple');
$this->RemovePermission('ShopMS_MaintainCategory');
$this->RemovePermission('ShopMS_MaintainProducts');
$this->RemovePermission('ShopMS_MaintainSKUs');

// Remove style sheet that belong to this module
$css_name = $this->Lang('module_example_stylesheet'); // Retrieve the name of the new stylesheet locate in the css directory
$query = 'DELETE FROM '.cms_db_prefix().'css WHERE css_name = ?';
$db->Execute($query, array($css_name));

// Remove all the search index entries
$searchmodule =& $this->GetModuleInstance('Search');
if ($searchmodule != FALSE) {
	$searchmodule->DeleteWords($this->GetName());
}

// Remove templates that belong to this module
$this->DeleteTemplate('', 'ShopMadeSimple');

$this->Audit( 0, $this->Lang('friendlyname'), $this->Lang('uninstalled',$this->GetVersion()));
?>
